@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import uuid
 import vobject
 import dateutil.tz
@@ -11,7 +11,7 @@ from sql import Table, Column
 from trytond.model import Model, ModelSQL, ModelView, fields
 from trytond.tools import reduce_ids, grouped_slice
 from trytond import backend
-from trytond.pyson import If, Bool, Eval
+from trytond.pyson import If, Bool, Eval, PYSONEncoder
 from trytond.transaction import Transaction
 from trytond.cache import Cache
 from trytond.pool import Pool
@@ -121,24 +121,6 @@ class Calendar(ModelSQL, ModelView):
             ical.vevent_list.extend(ical2.vevent_list)
         return ical
 
-    @property
-    def _fbtype(self):
-        '''
-        Return the freebusy type for give transparent and status
-        '''
-        if self.transp == 'opaque':
-            if not self.status or self.status == 'confirmed':
-                fbtype = 'BUSY'
-            elif self.status == 'cancelled':
-                fbtype = 'FREE'
-            elif self.status == 'tentative':
-                fbtype = 'BUSY-TENTATIVE'
-            else:
-                fbtype = 'BUSY'
-        else:
-            fbtype = 'FREE'
-        return fbtype
-
     @classmethod
     def freebusy(cls, calendar_id, dtstart, dtend):
         '''
@@ -163,7 +145,7 @@ class Calendar(ModelSQL, ModelView):
         else:
             ical.vfreebusy.add('dtend').value = dtend.astimezone(tzutc)
 
-        with Transaction().set_context(_check_access=False):
+        with Transaction().set_user(0):
             events = Event.search([
                     ['OR',
                         [('dtstart', '<=', dtstart),
@@ -200,7 +182,7 @@ class Calendar(ModelSQL, ModelView):
                 freebusy_dtstart.astimezone(tzutc),
                 freebusy_dtend.astimezone(tzutc))]
 
-        with Transaction().set_context(_check_access=False):
+        with Transaction().set_user(0):
             events = Event.search([
                     ('parent', '=', None),
                     ('dtstart', '<=', dtend),
@@ -217,7 +199,6 @@ class Calendar(ModelSQL, ModelView):
         for event in events:
             event_ical = event.event2ical()
             if event_ical.vevent.rruleset:
-                between_dtstart, between_dtend = dtstart, dtend
                 for freebusy_dtstart in event_ical.vevent.rruleset:
                     if freebusy_dtstart.replace(tzinfo=tzlocal) > dtend:
                         break
@@ -320,7 +301,7 @@ class Calendar(ModelSQL, ModelView):
                 email = attendee.value
                 if attendee.value.lower().startswith('mailto:'):
                     email = attendee.value[7:]
-                with Transaction().set_context(_check_access=False):
+                with Transaction().set_user(0):
                     calendars = cls.search([
                             ('owner.email', '=', email),
                             ])
@@ -473,12 +454,6 @@ class Event(ModelSQL, ModelView):
             'invisible': ~Eval('_parent_parent'),
             'required': Bool(Eval('_parent_parent')),
             }, depends=['parent'])
-    calendar_owner = fields.Function(fields.Many2One('res.user', 'Owner'),
-            'get_calendar_field', searcher='search_calendar_field')
-    calendar_read_users = fields.Function(fields.Many2One('res.user',
-        'Read Users'), 'get_calendar_field', searcher='search_calendar_field')
-    calendar_write_users = fields.Function(fields.One2Many('res.user', None,
-        'Write Users'), 'get_calendar_field', searcher='search_calendar_field')
     vevent = fields.Binary('vevent')
 
     @classmethod
@@ -497,13 +472,14 @@ class Event(ModelSQL, ModelView):
         # Migrate from 1.4: remove classification_public
         ModelData = Pool().get('ir.model.data')
         Rule = Pool().get('ir.rule')
-        models_data = ModelData.search([
-                ('fs_id', '=', 'rule_group_read_calendar_line3'),
-                ('module', '=', module_name),
-                ], limit=1)
-        if models_data:
-            model_data, = models_data
-            Rule.delete([Rule(model_data.db_id)])
+        with Transaction().set_user(0):
+            models_data = ModelData.search([
+                    ('fs_id', '=', 'rule_group_read_calendar_line3'),
+                    ('module', '=', module_name),
+                    ], limit=1)
+            if models_data:
+                model_data, = models_data
+                Rule.delete([Rule(model_data.db_id)])
         return super(Event, cls).__register__(module_name)
 
     @staticmethod
@@ -526,18 +502,23 @@ class Event(ModelSQL, ModelView):
     def timezones():
         return [(x, x) for x in pytz.common_timezones] + [('', '')]
 
-    def get_calendar_field(self, name):
-        assert name in ('calendar_owner', 'calendar_read_users',
-                'calendar_write_users'), 'Invalid name'
-        name = name[9:]
-        if name in ('read_users', 'write_users'):
-            return [x.id for x in getattr(self.calendar, name)]
+    @property
+    def _fbtype(self):
+        '''
+        Return the freebusy type for give transparent and status
+        '''
+        if self.transp == 'opaque':
+            if not self.status or self.status == 'confirmed':
+                fbtype = 'BUSY'
+            elif self.status == 'cancelled':
+                fbtype = 'FREE'
+            elif self.status == 'tentative':
+                fbtype = 'BUSY-TENTATIVE'
+            else:
+                fbtype = 'BUSY'
         else:
-            return getattr(self.calendar, name).id
-
-    @classmethod
-    def search_calendar_field(cls, name, clause):
-        return [('calendar.' + name[9:],) + tuple(clause[1:])]
+            fbtype = 'FREE'
+        return fbtype
 
     @classmethod
     def validate(cls, events):
@@ -557,6 +538,12 @@ class Event(ModelSQL, ModelView):
                     or self.occurences:
                 self.raise_user_error('invalid_recurrence', (self.rec_name,))
 
+    @classmethod
+    def view_attributes(cls):
+        return [('//page[@id="occurences"]', 'states', {
+                    'invisible': Bool(Eval('_parent_parent')),
+                    })]
+
     @classmethod
     def create(cls, vlist):
         pool = Pool()
@@ -579,7 +566,7 @@ class Event(ModelSQL, ModelView):
                             if x.status != 'declined'
                             and x.email != event.parent.organizer]
                 if attendee_emails:
-                    with Transaction().set_context(_check_access=False):
+                    with Transaction().set_user(0):
                         calendars = Calendar.search([
                                 ('owner.email', 'in', attendee_emails),
                                 ])
@@ -682,7 +669,7 @@ class Event(ModelSQL, ModelView):
                             for x in event.parent.attendees
                             if x.status != 'declined'
                             and x.email != event.parent.organizer]
-                    with Transaction().set_context(_check_access=False):
+                    with Transaction().set_user(0):
                         events2 = cls.search([
                                 ('uuid', '=', event.uuid),
                                 ('id', '!=', event.id),
@@ -698,7 +685,7 @@ class Event(ModelSQL, ModelView):
                         if events2:
                             cls.write(events2, event._event2update())
                     if attendee_emails:
-                        with Transaction().set_context(_check_access=False):
+                        with Transaction().set_user(0):
                             calendars = Calendar.search([
                                     ('owner.email', 'in', attendee_emails),
                                     ])
@@ -764,7 +751,7 @@ class Event(ModelSQL, ModelView):
                     attendee_emails = [x.email for x in event.parent.attendees
                             if x.email != event.parent.organizer]
                 if attendee_emails:
-                    with Transaction().set_context(_check_access=False):
+                    with Transaction().set_user(0):
                         cls.delete(cls.search([
                                     ('uuid', '=', event.uuid),
                                     ('calendar.owner.email', 'in',
@@ -778,7 +765,7 @@ class Event(ModelSQL, ModelView):
                     organizer = event.organizer
                 else:
                     organizer = event.parent.organizer
-                with Transaction().set_context(_check_access=False):
+                with Transaction().set_user(0):
                     events2 = cls.search([
                             ('uuid', '=', event.uuid),
                             ('calendar.owner.email', '=', organizer),
@@ -879,7 +866,8 @@ class Event(ModelSQL, ModelView):
             res['status'] = vevent.status.value.lower()
         else:
             res['status'] = ''
-        res['categories'] = [('remove', [c.id for c in event.categories])]
+        if event:
+            res['categories'] = [('remove', [c.id for c in event.categories])]
         if hasattr(vevent, 'categories'):
             with Transaction().set_context(active_test=False):
                 categories = Category.search([
@@ -902,7 +890,7 @@ class Event(ModelSQL, ModelView):
                     dict(cls.classification.selection):
                 res['classification'] = getattr(vevent, 'class').value.lower()
             else:
-                res['classification'] = 'public'
+                res['classification'] = 'private'
         else:
             res['classification'] = 'public'
         if hasattr(vevent, 'location'):
@@ -1405,7 +1393,7 @@ class EventAttendee(AttendeeMixin, ModelSQL, ModelView):
                     attendee_emails = [x.email for x in event.parent.attendees
                             if x.email != event.parent.organizer]
                 if attendee_emails:
-                    with Transaction().set_context(_check_access=False):
+                    with Transaction().set_user(0):
                         events = Event.search([
                                 ('uuid', '=', event.uuid),
                                 ('calendar.owner.email', 'in',
@@ -1455,7 +1443,7 @@ class EventAttendee(AttendeeMixin, ModelSQL, ModelView):
                     attendee_emails = [x.email for x in event.parent.attendees
                             if x.email != event.parent.organizer]
                 if attendee_emails:
-                    with Transaction().set_context(_check_access=False):
+                    with Transaction().set_user(0):
                         other_attendees = cls.search([
                                 ('event.uuid', '=', event.uuid),
                                 ('event.calendar.owner.email', 'in',
@@ -1492,7 +1480,7 @@ class EventAttendee(AttendeeMixin, ModelSQL, ModelView):
                     attendee_emails = [x.email for x in event.parent.attendees
                             if x.email != event.parent.organizer]
                 if attendee_emails:
-                    with Transaction().set_context(_check_access=False):
+                    with Transaction().set_user(0):
                         attendees = cls.search([
                                 ('event.uuid', '=', event.uuid),
                                 ('event.calendar.owner.email', 'in',
@@ -1511,7 +1499,7 @@ class EventAttendee(AttendeeMixin, ModelSQL, ModelView):
                     organizer = event.organizer
                 else:
                     organizer = event.parent.organizer
-                with Transaction().set_context(_check_access=False):
+                with Transaction().set_user(0):
                     attendees = cls.search([
                             ('event.uuid', '=', event.uuid),
                             ('event.calendar.owner.email', '=', organizer),
